"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _reactNative = require("react-native");

var _reactNativePaper = require("react-native-paper");

var _checkBox = _interopRequireDefault(require("../components/checkBox"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

const PaperSelect = ({
  // Required props
  label,
  arrayList,
  selectedArrayList,
  multiEnable,
  value,
  onSelection,
  // Core props
  disabled = false,
  hideSearchBox = false,
  selectAllEnable = true,
  textInputMode = 'flat',
  theme: themeOverrides,
  inputRef,
  limit = null,
  limitError = `You can't select more than ${limit} items.`,
  limitErrorStyle,
  // Localization props
  dialogTitle,
  selectAllText = 'Select all',
  searchText = 'Search',
  dialogCloseButtonText = 'Close',
  dialogDoneButtonText = 'Done',
  errorText,
  // Style props
  containerStyle,
  textInputStyle,
  textInputOutlineStyle,
  dialogStyle,
  dialogTitleStyle,
  searchStyle,
  dialogCloseButtonStyle,
  dialogDoneButtonStyle,
  errorStyle,
  textColor,
  // Component props
  textInputProps: textInputPropOverrides,
  checkboxProps: checkboxPropsOverrides,
  searchbarProps: searchbarPropsOverrides
}) => {
  var _textInputPropOverrid;

  const theme = (0, _reactNativePaper.useTheme)(themeOverrides);
  const textInputProps = {
    underlineColor: (textInputPropOverrides === null || textInputPropOverrides === void 0 ? void 0 : textInputPropOverrides.underlineColor) || 'black',
    activeUnderlineColor: (textInputPropOverrides === null || textInputPropOverrides === void 0 ? void 0 : textInputPropOverrides.activeUnderlineColor) || 'black',
    outlineColor: (textInputPropOverrides === null || textInputPropOverrides === void 0 ? void 0 : textInputPropOverrides.outlineColor) || 'black',
    activeOutlineColor: (textInputPropOverrides === null || textInputPropOverrides === void 0 ? void 0 : textInputPropOverrides.activeOutlineColor) || 'black',
    left: textInputPropOverrides === null || textInputPropOverrides === void 0 ? void 0 : textInputPropOverrides.left,
    right: (_textInputPropOverrid = textInputPropOverrides === null || textInputPropOverrides === void 0 ? void 0 : textInputPropOverrides.right) !== null && _textInputPropOverrid !== void 0 ? _textInputPropOverrid : /*#__PURE__*/_react.default.createElement(_reactNativePaper.TextInput.Icon, {
      style: styles.textInputIcon,
      size: 20,
      icon: "chevron-down"
    })
  };

  const {
    height
  } = _reactNative.Dimensions.get('window');

  const [searchKey, setSearchKey] = (0, _react.useState)('');
  const [arrayHolder, setArrayHolder] = (0, _react.useState)([...arrayList]);
  const [list, setList] = (0, _react.useState)([...arrayList]);
  const [selectedList, setSelectedList] = (0, _react.useState)([...selectedArrayList]);
  const [maxLimit, setMaxLimit] = (0, _react.useState)(list.length);
  const [hasDisabled, setHasDisabled] = (0, _react.useState)(false);
  const [showLimitError, setShowLimitError] = (0, _react.useState)(false);
  const selfInputRef = (0, _react.useRef)(null);
  const selectInputRef = inputRef !== null && inputRef !== void 0 ? inputRef : selfInputRef;
  const [visible, setVisible] = (0, _react.useState)(false);
  (0, _react.useEffect)(() => {
    let isMounted = true;

    let _getData = async () => {
      if (isMounted && showLimitError) {
        setTimeout(() => {
          setShowLimitError(false);
        }, 10000);
      }
    };

    _getData();

    return () => {
      isMounted = false;
    };
  }, [showLimitError]);

  const showDialog = () => setVisible(true);

  const _hideDialog = () => {
    setSearchKey('');
    var data = [...arrayHolder]; // console.log(selectedList);

    var selectedData = [...selectedList]; // console.log(selectedData);

    let finalText = '';
    selectedData.forEach((val, index) => {
      data.forEach(el => {
        if (val._id === el._id) {
          finalText += index !== selectedData.length - 1 ? `${el.value}, ` : `${el.value}`;
        }
      });
    });
    onSelection({
      text: finalText,
      selectedList: selectedData
    });
    setVisible(false);

    if (selectInputRef && selectInputRef.current) {
      selectInputRef.current.blur();
    }
  };

  const _closeDialog = () => {
    setVisible(false);
    setSearchKey('');

    if (selectInputRef && selectInputRef.current) {
      selectInputRef.current.blur();
    }
  };

  const _onFocus = () => {
    setArrayHolder([...arrayList]);
    setList([...arrayList]);
    setMaxLimit([...arrayList].length);
    setHasDisabled(_checkIfAnyItemDisabled([...arrayList]));
    setSelectedList([...selectedArrayList]);
    showDialog();
  };

  const _onChecked = item => {
    var selectedData = [...selectedList]; // const index = data.findIndex(x => x._id === item._id);

    const indexSelected = selectedData.findIndex(val => val._id === item._id);

    if (indexSelected > -1) {
      selectedData.splice(indexSelected, 1);
    } else {
      if (limit && selectedData.length === limit) {
        setShowLimitError(true);
      } else {
        setShowLimitError(false);
        selectedData.push(item);
      }
    }

    setSelectedList([...selectedData]);
  };

  const _onCheckedSingle = item => {
    var selectedData = [...selectedList]; // const index = data.findIndex(x => x._id === item._id);

    const indexSelected = selectedData.findIndex(val => val._id === item._id);

    if (indexSelected > -1) {
      // selectedData.splice(indexSelected, 1);
      selectedData = [];
    } else {
      selectedData = [];
      selectedData.push(item);
    } // console.log(selectedData);


    setSelectedList([...selectedData]);
  };

  const _exists = item => {
    // console.log(selectedList);
    let _temp = [...selectedList];
    return _temp.find(val => val._id === item._id) ? true : false;
  };

  const _isCheckedAll = () => {
    const data = [...list];
    const selectedData = [...selectedList];
    return selectedData.length !== 0 && selectedData.length === data.length;
  };

  const _checkAll = () => {
    const data = [...list];
    var selectedData = [...selectedList];

    if (selectedData.length === data.length) {
      selectedData = [];
    } else if (selectedData.length === 0 || selectedData.length > 0) {
      selectedData = data.slice(0);
    }

    setSelectedList([...selectedData]);
  };

  const _renderItem = ({
    item
  }) => /*#__PURE__*/_react.default.createElement(_checkBox.default, _extends({}, checkboxPropsOverrides, {
    isChecked: _exists(item),
    label: item.value,
    onPress: () => {
      multiEnable === true ? _onChecked(item) : _onCheckedSingle(item);
    },
    disabled: item.disabled
  }));

  const _filterFunction = text => {
    setSearchKey(text);
    const newData = arrayHolder.filter(item => item.value.toLowerCase().includes(text.toLowerCase()));
    setList(newData);
  };

  const _checkIfAnyItemDisabled = _list => {
    const data = [..._list];
    let result = data.find(x => x.disabled);
    return result ? true : false;
  };

  return /*#__PURE__*/_react.default.createElement(_reactNativePaper.ThemeProvider, {
    theme: theme
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [styles.container, containerStyle]
  }, /*#__PURE__*/_react.default.createElement(_reactNativePaper.TextInput, _extends({}, textInputProps, {
    ref: selectInputRef,
    disabled: disabled,
    style: [styles.textInput, textInputStyle],
    outlineStyle: textInputOutlineStyle,
    label: label,
    mode: textInputMode,
    onFocus: disabled ? undefined : _onFocus,
    showSoftInputOnFocus: false,
    value: value,
    textColor: textColor
  })), errorText ? /*#__PURE__*/_react.default.createElement(_reactNativePaper.Text, {
    style: [{
      color: theme.colors.error
    }, errorStyle]
  }, errorText) : null), /*#__PURE__*/_react.default.createElement(_reactNative.View, null, /*#__PURE__*/_react.default.createElement(_reactNativePaper.Portal, null, /*#__PURE__*/_react.default.createElement(_reactNativePaper.Dialog, {
    style: [styles.dialog, dialogStyle],
    visible: visible,
    dismissable: false
  }, /*#__PURE__*/_react.default.createElement(_reactNativePaper.Dialog.Title, {
    style: dialogTitleStyle
  }, dialogTitle !== null && dialogTitle !== void 0 ? dialogTitle : label), /*#__PURE__*/_react.default.createElement(_reactNativePaper.Dialog.ScrollArea, {
    style: {
      paddingHorizontal: 14
    }
  }, !hideSearchBox ? /*#__PURE__*/_react.default.createElement(_reactNativePaper.Searchbar, _extends({}, searchbarPropsOverrides, {
    value: searchKey,
    placeholder: searchText,
    onChangeText: text => _filterFunction(text),
    style: [styles.searchbar, searchStyle]
  })) : null, /*#__PURE__*/_react.default.createElement(_reactNative.FlatList, {
    ListHeaderComponent: multiEnable === true && selectAllEnable === true ? /*#__PURE__*/_react.default.createElement(_checkBox.default, _extends({}, checkboxPropsOverrides, {
      isChecked: _isCheckedAll(),
      label: selectAllText,
      onPress: () => {
        _checkAll();
      },
      disabled: hasDisabled || limit && limit > 0 && limit !== maxLimit ? true : false
    })) : null,
    data: list,
    renderItem: _renderItem,
    keyExtractor: item => item._id.toString(),
    keyboardShouldPersistTaps: "handled",
    style: (styles.dialogScrollView, {
      maxHeight: height - height * 45 / 100,
      marginBottom: 8
    })
  }), showLimitError ? /*#__PURE__*/_react.default.createElement(_reactNativePaper.Text, {
    style: [{
      color: theme.colors.error
    }, limitErrorStyle]
  }, limitError) : null), /*#__PURE__*/_react.default.createElement(_reactNativePaper.Dialog.Actions, null, /*#__PURE__*/_react.default.createElement(_reactNativePaper.Button, {
    labelStyle: dialogCloseButtonStyle,
    onPress: _closeDialog
  }, dialogCloseButtonText), /*#__PURE__*/_react.default.createElement(_reactNativePaper.Button, {
    labelStyle: dialogDoneButtonStyle,
    onPress: _hideDialog
  }, dialogDoneButtonText))))));
};

const styles = _reactNative.StyleSheet.create({
  container: {
    width: '100%',
    marginBottom: 10
  },
  dialog: {
    borderRadius: 5
  },
  dialogScrollView: {
    width: '100%'
  },
  textInput: {// backgroundColor: '#fff',
    // color: '#000',
  },
  textInputIcon: {
    justifyContent: 'center',
    alignItems: 'center',
    alignSelf: 'center',
    alignContent: 'center'
  },
  searchbar: {
    borderColor: '#777777',
    backgroundColor: '#F1F1F2',
    borderWidth: 0.25,
    marginBottom: 10,
    marginHorizontal: 8,
    color: '#000',
    marginTop: 12
  }
});

var _default = /*#__PURE__*/(0, _react.memo)(PaperSelect);

exports.default = _default;
//# sourceMappingURL=paperSelect.js.map